package de.jottyfan.quickiemod.init;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import de.jottyfan.quickiemod.QuickieMod;
import de.jottyfan.quickiemod.blockentity.BlockEntityTypes;
import de.jottyfan.quickiemod.blocks.QuickieBlocks;
import de.jottyfan.quickiemod.event.BreakBlockCallback;
import de.jottyfan.quickiemod.event.EventBlockBreak;
import de.jottyfan.quickiemod.items.QuickieItems;
import net.fabricmc.fabric.api.biome.v1.BiomeModifications;
import net.fabricmc.fabric.api.biome.v1.BiomeSelectors;
import net.fabricmc.fabric.api.biome.v1.ModificationPhase;
import net.fabricmc.fabric.api.itemgroup.v1.FabricItemGroup;
import net.fabricmc.fabric.api.registry.FuelRegistry;
import net.minecraft.block.ComposterBlock;
import net.minecraft.item.BlockItem;
import net.minecraft.item.Item.Settings;
import net.minecraft.item.ItemStack;
import net.minecraft.registry.Registries;
import net.minecraft.registry.Registry;
import net.minecraft.registry.RegistryKey;
import net.minecraft.registry.RegistryKeys;
import net.minecraft.text.Text;
import net.minecraft.util.ActionResult;
import net.minecraft.util.Identifier;

/**
 *
 * @author jotty
 *
 */
public class RegistryManager {
	private static final Logger LOGGER = LoggerFactory.getLogger(QuickieMod.MODID);

	public static final void registerItemGroup() {
		Registry.register(Registries.ITEM_GROUP, RegistryKey.of(RegistryKeys.ITEM_GROUP, Identifier.of(QuickieMod.MODID, "itemgroups")),
				FabricItemGroup.builder().icon(() -> new ItemStack(QuickieItems.ROTTEN_FLESH_STRIPES.getItem())).displayName(Text.literal(QuickieMod.MODID))
						.entries((enabledFeatures, stacks) -> {
							for (QuickieItems i : QuickieItems.values()) {
								stacks.add(new ItemStack(i.getItem()));
							}
							for (QuickieBlocks b : QuickieBlocks.values()) {
								if (b.getAdd2BlockPanel()) {
									stacks.add(new ItemStack(b.getBlock()));
								}
							}
						}).build());
	}

	public static final void registerItems() {
		LOGGER.info("registering items");
		for (QuickieItems i : QuickieItems.values()) {
			Registry.register(Registries.ITEM, Identifier.of(QuickieMod.MODID, i.getName()), i.getItem());
		}
		ComposterBlock.ITEM_TO_LEVEL_INCREASE_CHANCE.put(QuickieItems.COTTONSEED.getItem(), 0.5f);
		ComposterBlock.ITEM_TO_LEVEL_INCREASE_CHANCE.put(QuickieItems.COTTON.getItem(), 0.75f);
		ComposterBlock.ITEM_TO_LEVEL_INCREASE_CHANCE.put(QuickieItems.CANOLASEED.getItem(), 0.5f);
		ComposterBlock.ITEM_TO_LEVEL_INCREASE_CHANCE.put(QuickieItems.CANOLA.getItem(), 0.75f);
		FuelRegistry.INSTANCE.add(QuickieItems.SULPHOR.getItem(), 200);
		FuelRegistry.INSTANCE.add(QuickieBlocks.BLOCKSULPHOR.getBlock(), 2000);
	}

	public static final void registerBlocks() {
		LOGGER.info("registering blocks");
		for (QuickieBlocks b : QuickieBlocks.values()) {
			Registry.register(Registries.BLOCK, Identifier.of(QuickieMod.MODID, b.getName()), b.getBlock());
			Registry.register(Registries.ITEM, Identifier.of(QuickieMod.MODID, b.getName()), new BlockItem(b.getBlock(), new Settings()));
		}
	}

	public static final void registerFeatures() {
		// Overworld features
		BiomeModifications.create(Identifier.of(QuickieMod.MODID, "features")).add(ModificationPhase.ADDITIONS, BiomeSelectors.foundInOverworld(),
				FeaturesManager.overworldOres());

		// Nether features
		BiomeModifications.create(Identifier.of(QuickieMod.MODID, "nether_features")).add(ModificationPhase.ADDITIONS, BiomeSelectors.foundInTheNether(),
				FeaturesManager.netherOres());
	}

	public static final void registerEvents() {
		LOGGER.info("registering events");
		BreakBlockCallback.EVENT.register((world, blockPos, blockState, playerEntity) -> {
			new EventBlockBreak().doBreakBlock(world, blockPos, blockState, playerEntity);
			return ActionResult.SUCCESS;
		});
	}

	public static final void registerBlockEntityTypes() {
		try {
			Class.forName(BlockEntityTypes.class.getName());
			LOGGER.info("registering block entity types");
		} catch (ClassNotFoundException e) {
			LOGGER.error("class BlockEntityType not loaded", e);
		}
	}

	public static final void registerScreenHandlerTypes() {
	}
}
